@@ -86,6 +86,7 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Filter;
 import com.openexchange.config.cascade.ConfigProviderService;
 import com.openexchange.context.ContextService;
+import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
@@ -276,9 +277,8 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
      * @param e The messaging error to handle
      * @param config The associated configuration
      * @return The appropriate {@code OXException} instance
-     * @throws OXException If appropriate {@code OXException} instance cannot be returned
      */
-    protected OXException handleMessagingException(MessagingException e, MailConfig config) throws OXException {
+    protected OXException handleMessagingException(MessagingException e, MailConfig config) {
         return MimeMailException.handleMessagingException(e, config, null);
     }
 
@@ -420,6 +420,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                         try {
                             internetAddress.setPersonal("", "US-ASCII");
                         } catch (final UnsupportedEncodingException e) {
+                            LOG.trace("\"US-ASCII\" is not supported", e);
                             // Ignore as personal is cleared
                         }
                     }
@@ -560,6 +561,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                                 throw MailExceptionCode.NON_SECURE_DENIED.create(smtpConfig.getServer());
                             }
                         } catch (final IOException e) {
+                            LOG.trace("Failed to determine SMTP server capabilities", e);
                             smtpProps.put("mail.smtp.starttls.enable", "true");
                         }
                         /*
@@ -843,7 +845,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                             OAuthAccount oAuthAccount = oauthService.getAccount(session, oauthAccountId);
                             API api = oAuthAccount.getAPI();
                             Throwable cause = e.getCause();
-                            throw OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.create(cause, api.getName(), I(oAuthAccount.getId()), I(session.getUserId()), I(session.getContextId()));
+                            throw OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.create(cause, api.getDisplayName(), I(oAuthAccount.getId()), I(session.getUserId()), I(session.getContextId()));
                         } catch (Exception x) {
                             LOG.warn("Failed to handle failed OAuth authentication", x);
                         }
@@ -912,7 +914,8 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
      */
     protected MimeMessage transport(MimeMessage smtpMessage, Address[] recipients, javax.mail.Session smtpSession, SMTPConfig smtpConfig, MtaStatusInfo mtaInfo, SecuritySettings securitySettings) throws OXException {
         // Prepare addresses
-        prepareAddresses(recipients);
+        Address[] recipientz = recipients;
+        prepareAddresses(recipientz);
 
         Transport transport = null;
         try {
@@ -937,7 +940,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                 }
 
                 // Check listener chain
-                Result result = listenerChain.onBeforeMessageTransport(messageToSend, recipients, securitySettings, session);
+                Result result = listenerChain.onBeforeMessageTransport(messageToSend, recipientz, securitySettings, session);
 
                 // Examine reply of the listener chain
                 {
@@ -952,9 +955,9 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                         return result.getMimeMessage();
                     }
                     // Check recipient list from result
-                    recipients = result.getRecipients();
+                    recipientz = result.getRecipients();
                     // If not recipients, no need to continue sending.
-                    if (recipients == null || recipients.length == 0) {
+                    if (recipientz == null || recipientz.length == 0) {
                         return result.getMimeMessage();
                     }
 
@@ -991,7 +994,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
 
                 // Transport
                 long start = System.currentTimeMillis();
-                doTransport(messageToSend, recipients, transport);
+                doTransport(messageToSend, recipientz, transport);
                 mailInterfaceMonitor.addUseTime(System.currentTimeMillis() - start);
                 logMessageTransport(messageToSend, smtpConfig);
             } catch (OXException e) {
@@ -1054,8 +1057,12 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         if (null != transport) {
             try {
                 transport.close();
-            } catch (final MessagingException e) {
-                LOG.error("Closing SMTP transport failed.", e);
+            } catch (MessagingException e) {
+                if (ExceptionUtils.isEitherOf(e, java.net.SocketException.class)) {
+                    // Connection already closed by remote host
+                } else {
+                    LOG.error("Closing SMTP transport failed.", e);
+                }
             }
         }
     }
@@ -1129,6 +1136,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
 
     @Override
     public MailMessage sendMailMessage(ComposedMailMessage composedMail, ComposeType sendType, Address[] allRecipients, MtaStatusInfo mtaStatusInfo) throws OXException {
+        Address[] allRecipientz = allRecipients;
         final SMTPConfig smtpConfig = getTransportConfig();
         try {
             /*
@@ -1157,6 +1165,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                         smtpFiller.setCommonHeaders(mimeMessage);
                     }
                 } catch (final Exception e) {
+                    LOG.trace("Failed to extract MIME message from {} instance", ContentAware.class.getName(), e);
                     mimeMessage = null;
                 }
             }
@@ -1189,11 +1198,11 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                     /*
                      * Check recipients
                      */
-                    if (allRecipients == null) {
+                    if (allRecipientz == null) {
                         if (composedMail.hasRecipients()) {
-                            allRecipients = composedMail.getRecipients();
+                            allRecipientz = composedMail.getRecipients();
                         } else {
-                            allRecipients = smtpMessage.getAllRecipients();
+                            allRecipientz = smtpMessage.getAllRecipients();
                         }
                     }
 
@@ -1209,7 +1218,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                 }
             }
 
-            MimeMessage sentMimeMessage = sendMimeMessage(mimeMessage, allRecipients, mtaStatusInfo, composedMail.getSecuritySettings());
+            MimeMessage sentMimeMessage = sendMimeMessage(mimeMessage, allRecipientz, mtaStatusInfo, composedMail.getSecuritySettings());
             return MimeMessageConverter.convertMessage(sentMimeMessage);
         } catch (final MessagingException e) {
             throw handleMessagingException(e, smtpConfig);
@@ -1405,14 +1414,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
     }
 
     private int getUserId() {
-        int userId;
-        if (user == null) {
-            userId = ConfigProviderService.NO_USER;
-        } else {
-            userId = user.getId();
-        }
-
-        return userId;
+        return user == null ? ConfigProviderService.NO_USER : user.getId();
     }
 
     private void prepareAddresses(final Address[] addresses) {
@@ -1433,15 +1435,16 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
 
     private String getHostName() {
         final HostnameService hostnameService = Services.getService(HostnameService.class);
-        String hostName;
         if (null == hostnameService) {
-            hostName = getFallbackHostname();
+            return getFallbackHostname();
+        }
+
+        String hostName;
+        User user = this.user;
+        if (null != user && user.isGuest()) {
+            hostName = hostnameService.getGuestHostname(user.getId(), ctx.getContextId());
         } else {
-            if (null != user && user.isGuest()) {
-                hostName = hostnameService.getGuestHostname(getUserId(), ctx.getContextId());
-            } else {
-                hostName = hostnameService.getHostname(getUserId(), ctx.getContextId());
-            }
+            hostName = hostnameService.getHostname(getUserId(), ctx.getContextId());
         }
         if (null == hostName) {
             hostName = getFallbackHostname();
@@ -1476,6 +1479,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                 try {
                     content = part.getContent();
                 } catch (Exception e) {
+                    LOG.trace("Failed to acquire MIME part's content", e);
                     content = null;
                 }
                 if (content instanceof MimeMessage) {
@@ -1491,10 +1495,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
 
     private String getFallbackHostname() {
         final String serverName = LogProperties.getLogProperty(LogProperties.Name.GRIZZLY_SERVER_NAME);
-        if (null == serverName) {
-            return getStaticHostName();
-        }
-        return serverName;
+        return null == serverName ? getStaticHostName() : serverName;
     }
 
     private static String getStaticHostName() {
@@ -1560,9 +1561,9 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                     message.addHeader(header, mail);
                 }
             } catch (MessagingException e) {
-                LOG.error("Couldn't add header to the outgoing mail.", e);
+                LOG.error("Couldn't add header {} to the outgoing mail.", header, e);
             } catch (OXException e) {
-                LOG.error("The user {} in context {} wasn't found. Therefore the header {} wasn't appended to the message.", I(session.getUserId()), I(session.getContextId()), header);
+                LOG.error("The user {} in context {} wasn't found. Therefore the header {} wasn't appended to the message.", I(session.getUserId()), I(session.getContextId()), header, e);
             }
         }
     }
